/*---------------------------------------------------------------------------\
| Project:	Generic LV2 PIC18F458 CAN node firmware
|
| File:		interrupts.h
|
| Descr.:	Includes for the serial.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _INTS_H	// Don't include more than once (last line = #endif)
#define _INTS_H

//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------

enum INTERRUPT_TYPE
{
	LOW_PRIORITY_INT = 0,
	HIGH_PRIORITY_INT
};

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------


//------------------------------------------------------------------------
// Global function declarations
//------------------------------------------------------------------------

void InitializeInterrupts (void);

void interrupt low_priority LowPriorityISR 	(void);
void interrupt 				HighPriorityISR	(void);


//------------------------------------------------------------------------
// #define'd function declarations (for easier reading)
//------------------------------------------------------------------------


#define	EnablePrioritizedInts()		(IPEN = 1)
#define	DisablePrioritizedInts()	(IPEN = 0)

#define	EnableHighPriorityInts()	(GIEH = 1)
#define	DisableHighPriorityInts()	(GIEH = 0)

#define EnableLowPriorityInts()		(GIEL = 1)
#define DisableLowPriorityInts()	(GIEL = 0)

#define Timer2PrioritySetting()		TMR2IP
#define Timer2InterruptPending()	TMR2IF

#define	SerialTxPrioritySetting()	TXIP
#define SerialTxInterruptPending()	TXIF

#define	SerialRxPrioritySetting()	RCIP
#define SerialRxInterruptPending()	RCIF

#define CanTxb2PrioritySetting()	TXB2IP
#define CanTxb2InterruptPending()	TXB2IF

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// INTERRUPT PRIORITY DEFINED HERE. ONLY ONE #DEFINE PER PAIR MAY BE
// DEFINED; IN OTHER WORDS, CHOOSE EITHER HP OR LP.

#define	CANTXB2INT_HP
//#define	CANTXB2INT_LP

#define	TIMER2INT_HP
//#define	TIMER2INT_LP

//#define	SERIALTXINT_HP
#define	SERIALTXINT_LP

//#define	SERIALRXINT_HP
#define	SERIALRXINT_LP

// DON'T FORGET TO SET THE INTERRUPT PRIORITY BIT IN "InitializeInterrupts".

//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

// None


#endif			// _INTS_H
