/*---------------------------------------------------------------------------\
| Project:			Generic LV2 PIC18F458 CAN node firmware
|
| File:				ports.c
|
| Description:		Code which deals with the PIC18F458's I/O ports.
|
| Global Routines:	InitializePorts()
|
| Local Routines:	None
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/



//------------------------------------------------------------------------
//  #includes
//------------------------------------------------------------------------

#include <pic18.h>    	// Include for PICC-18
#include "pic18fxx8.h"	// Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (misc)
#include "ints.h"		// Includes for interrupts
#include "ports.h"		// Includes for the port peripherals
#include "excepts.h"	// Includes for exception handling




/*---------------------------------------------------------------------------\
| Function:		InitializePorts
|
| Purpose:		Initialize the PIC's ports out of reset.
|
| Discussion:	Huh?
|
| Expects:		All interupts to be off (after all, we were just reseted).
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 05/21/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void InitializePorts (void)
{

	//------------------------------------------------------------------------
	// PORTA: RA0 - RA5 (Caution: ADC, RA5)
	//------------------------------------------------------------------------

	LATA = 0;				// Port A output latch = all zeros
	ADCON1 = 0b00000110;	// Tell ADC peripheral to give up PORTA pins to PORTA
		 	// ||||||||
			// |||||||+----------- PCFG0 = 0110 = Port A is ALL digital outputs
		    // ||||||+------------ PCFG1    	  (i.e., not ADC inputs)
		    // |||||+------------- PCFG2
		    // ||||+-------------- PCFG3
		    // |||+--------------- <Unimplemented on PIC>
			// ||+---------------- <Unimplemented on PIC>
		    // |+----------------- ADCS2 = x
		    // +------------------ ADFM = x
	TRISA = 0xFF; 			// SAFE MODE: ALL INPUTS



	//------------------------------------------------------------------------
	// PORTB: RB0 - RB7 (Caution: ICD, CAN)
	//------------------------------------------------------------------------

	// PORTB PIN 3 (RB3) MUST BE SET TO ZERO!!!! OTHERWISE, A ONE WRITTEN
	// TO THE CAN BUS WILL BRING DOWN THE WHOLE DAMN BUS. WE'lL FIX THIS
	// POSSIBILITY IN THE NEXT ROUND OF HARDWARE - ADD A HIGH PASS FILTER
	// TO THE OUTPUT BETWEEN THE PIC AND THE TRANSCIEVER SO THAT
	// AFTER A SECOND OR SO THE OUTPUT IS ATTENUATED TO ZERO.

	LATB = 0;				// Port B output latch = all zeros
	RBPU = 1;				// Turn OFF Port B weak (~60kohm) pull-up resistors
	TRISB =  0b11111011;	// SAFE MODE: ALL INPUTS EXCEPT CANTX
		 	// ||||||||
			// |||||||+----------- RB0/INT0 	= out = ?
		    // ||||||+------------ RB1/INT1 	= out = ?
		    // |||||+------------- RB2/CANTX 	= out = CANTX
		    // ||||+-------------- RB3/CANRX 	= in  = CANRX
		    // |||+--------------- RB4 			= in  = ?
			// ||+---------------- RB5/PGM 		= in  = ?
		    // |+----------------- RB6/PGC 		= in  = ICD2 PGC
		    // +------------------ RB7/PGD 		= in  = ICD2 PGD

	//------------------------------------------------------------------------
	// PORTC: RC0 - RC7 (Caution: serial)
	//------------------------------------------------------------------------

	LATC = 0x00;		// Port C output latch = all zeros
	TRISC = 0xFF; 		// SAFE MODE: ALL INPUTS


	//------------------------------------------------------------------------
	// PORTD: RD0 - RD7
	//------------------------------------------------------------------------

	LATD = 0x00;		// Port D output latch = all zeros
	TRISD = 0xFF;		// SAFE MODE: all inputs


	//------------------------------------------------------------------------
	// PORTE: RE0 - RE2
	//------------------------------------------------------------------------


	LATE = 0x00;	// Port E output latch = all zeros
	TRISE = 0xFF; 	// SAFE MODE: all inputs
}



